var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import makeMessageBody from '#src/models/make-message-body';
import sendMessage from '#src/models/send-message/index';
import getReport from '#src/models/get-report/index';
import getCorrectError from '#src/utils/get-correct-error';
export function sendMessageAndGetResponse({ phoneNumber, messageTemplate, keyValue, sendType, profileKey, }) {
    return __awaiter(this, void 0, void 0, function* () {
        // create message body based on template
        const messageBody = makeMessageBody(phoneNumber, messageTemplate, keyValue, profileKey);
        // send notification message
        const sendMessageResponse = yield sendMessage(messageBody, sendType);
        // throw error if response code of the notification message === 'fail'
        if (sendMessageResponse.code === 'fail') {
            throw getCorrectError(sendMessageResponse);
        }
        // get notification report
        // wait for the message to be sent by Kakao w/ exponential backoff
        let getReportResponse = { code: '' };
        for (let i = 1; i <= 5; i++) {
            yield new Promise((resolve) => setTimeout(resolve, Math.pow(2, i) * 500));
            getReportResponse = yield getReport(sendMessageResponse.msgid, sendType, profileKey);
            if (getReportResponse.code == 'success') {
                break;
            }
        }
        // throw error if response code of the notification report === 'fail'
        if (getReportResponse.code === 'fail') {
            throw getCorrectError(getReportResponse);
        }
        // return unique message ID
        const cleanedJSON = { msgid: getReportResponse.msgid };
        return cleanedJSON;
    });
}
//# sourceMappingURL=send-message-and-get-response.js.map